@@ -1,4 +1,4 @@
 #! /usr/bin/env bash
 $EXTRACTRC `find . -name "*.ui"` >> rc.cpp || exit 11
-$XGETTEXT `find . -name "*.cpp"` -o $podir/kcm_telepathy_accounts.pot
+$XGETTEXT `find . -name "*.cpp"` -o $podir/telepathy-accounts-kcm.pot
 rm -f rc.cpp
